@@ -210,6 +210,31 @@ check_userinput_datanocov_estimationsplit <- function(estimation.split, date.for
   return(c())
 }
 
+#' @importFrom lubridate is.POSIXt is.Date parse_date_time
+check_userinput_datanocov_dataend <- function(data.end, date.format){
+
+  # May be NULL
+  if(is.null(data.end))
+    return(c())
+
+  if(length(data.end) != 1)
+    return("data.end must contain exactly one single element!")
+
+  if(anyNA(data.end))
+    return("data.end may not contain any NAs!")
+
+  if(!is.character(data.end)
+     & !is.Date(data.end)
+     & !is.POSIXt(data.end))
+    return("data.end needs to either of type character or date-like (Date or POSIXt)")
+
+  if(is.character(data.end))
+    if(anyNA(parse_date_time(x=data.end, quiet=TRUE, orders=date.format)))
+      return("Please provide a valid data.end to that can be converted with the given date.format!")
+
+  return(c())
+}
+
 
 #' @importFrom lubridate is.POSIXct
 check_userinput_datanocov_datatransactions <- function(data.transactions.dt, has.spending){
