@@ -218,9 +218,9 @@ fct.testthat.correctness.clvfittedtransactions.staticcov.regularization.lambda.0
 }
 
 fct.testthat.correctness.clvfittedtransactions.nocov.predict.newcustomer.0.for.num.periods.eq.0 <- function(clv.fitted){
-  test_that("nocov: predict newcustomer 0 for t=0", {
+  test_that("nocov: predict newcustomer==1 for t=0", {
     expect_silent(pred <- predict(clv.fitted, newdata=newcustomer(num.periods = 0)))
-    expect_true(pred == 0)
+    expect_true(pred == 1)
   })
 }
 
@@ -284,7 +284,7 @@ fct.testthat.correctness.clvfittedtransactions.staticcov.predict.newcustomer.dif
 }
 
 fct.testthat.correctness.clvfittedtransactions.staticcov.predict.newcustomer.0.for.num.periods.eq.0 <- function(m.fitted.static){
-  test_that("staticcov: predict(newcustomer) 0 for t=0", {
+  test_that("staticcov: predict(newcustomer)==1 for t=0", {
     df.cov <- fct.helper.default.newcustomer.covdata.static()
     expect_silent(pred <- predict(
       m.fitted.static,
@@ -292,7 +292,7 @@ fct.testthat.correctness.clvfittedtransactions.staticcov.predict.newcustomer.0.f
         num.periods = 0,
         data.cov.life = df.cov,
         data.cov.trans = df.cov)))
-    expect_true(pred == 0)
+    expect_true(pred == 1)
   })
 }
 
